==> vue-components-1.5.13.tgz: package/lib/drawer/src/Drawer.vue.rd.js <==
import { useInjectStyle as w } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as g, toRefs as S, openBlock as t, createBlock as u, unref as i, mergeProps as j, isRef as x, withCtx as f, createElementBlock as n, normalizeClass as a, createElementVNode as d, toDisplayString as p, createCommentVNode as o, renderSlot as B, createTextVNode as b } from "vue";
import { useVModel as D } from "@vueuse/core";
import N from "../../node_modules/ant-design-vue/es/drawer/index.rd.js";
import { drawerProps as T } from "./props.rd.js";
import $ from "../../node_modules/ant-design-vue/es/drawer/style/index.css.rd.js";
import "../../buttons/index.rd.js";
import y from "../../buttons/src/Button.vue.rd.js";
const A = { class: "flex flex-col justify-between" }, E = { class: "ml-auto h-full flex items-start justify-start" }, O = {
  key: 1,
  class: "border-t-gray-200 border-t-solid dark:border-t-slate-700 border-t pt-4 px-4 pb-4 flex absolute w-full bottom-0 justify-end mt-auto space-x-3"
}, q = /* @__PURE__ */ g({
  __name: "Drawer",
  props: T(),
  emits: ["update:visible"],
  setup(k, { emit: v }) {
    const l = k;
    w($, "ant-drawer");
    const { afterVisibleChange: s } = S(l), m = D(l, "visible");
    function c() {
      var e;
      v("update:visible", !1), (e = l.afterClose) == null || e.call(l);
    }
    const C = (...e) => {
      var r;
      (r = s == null ? void 0 : s.value) == null || r.call(s, ...e);
    };
    return (e, r) => (t(), u(i(N), j({
      visible: i(m),
      "onUpdate:visible": r[0] || (r[0] = (h) => x(m) ? m.value = h : null),
      title: null,
      footer: null,
      width: e.width,
      closable: !1,
      placement: e.placement,
      style: { padding: "0px" },
      drawerStyle: { padding: "0px" },
      bodyStyle: { padding: "0px" }
    }, e.$attrs, {
      onClose: c,
      onAfterVisibleChange: C
    }), {
      default: f(() => [
        e.title || e.closable ? (t(), n("div", {
          key: 0,
          class: a([[e.headerClass], "p-5 flex flex-row items-start"])
        }, [
          d("div", A, [
            e.title ? (t(), n("h2", {
              key: 0,
              class: a([[e.titleClass], "mb-0 font-bold text-theme"])
            }, p(e.title), 3)) : o("", !0),
            d("p", {
              class: a([[e.descriptionClass], "mt-1 mb-0"])
            }, p(e.description), 3)
          ]),
          d("div", E, [
            e.closable ? (t(), n("span", {
              key: 0,
              class: a([[e.closeClass], "text-3xl text-slate-500 cursor-pointer hoverable-close hover:text-slate-700 dark:hover:text-slate-100 i-ic-round-close"]),
              onClick: c
            }, null, 2)) : o("", !0)
          ])
        ], 2)) : o("", !0),
        d("div", {
          style: { height: "500px" },
          class: a([[e.bodyClass], "pb-4 px-5 pt-0"])
        }, [
          B(e.$slots, "default")
        ], 2),
        e.showFooter ? (t(), n("div", O, [
          e.onCancel ? (t(), u(i(y), {
            key: 0,
            type: "border",
            color: "neutro",
            onClick: e.onCancel
          }, {
            default: f(() => [
              b(p(e.cancelText), 1)
            ]),
            _: 1
          }, 8, ["onClick"])) : o("", !0),
          e.onOk ? (t(), u(i(y), {
            key: 1,
            color: "primary",
            onClick: e.onOk
          }, {
            default: f(() => [
              b(p(e.okText), 1)
            ]),
            _: 1
          }, 8, ["onClick"])) : o("", !0)
        ])) : o("", !0)
      ]),
      _: 3
    }, 16, ["visible", "width", "placement"]));
  }
});
export {
  q as default
};

==> vue-components-1.5.26.tgz: package/lib/drawer/src/Drawer.vue.rd.js <==
import { useInjectStyle as w } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as g, toRefs as S, openBlock as t, createBlock as u, unref as i, mergeProps as j, isRef as x, withCtx as f, createElementBlock as n, normalizeClass as a, createElementVNode as d, toDisplayString as p, createCommentVNode as o, renderSlot as B, createTextVNode as b } from "vue";
import { useVModel as D } from "@vueuse/core";
import N from "../../node_modules/ant-design-vue/es/drawer/index.rd.js";
import { drawerProps as T } from "./props.rd.js";
import $ from "../../node_modules/ant-design-vue/es/drawer/style/index.css.rd.js";
import "../../buttons/index.rd.js";
import y from "../../buttons/src/Button.vue.rd.js";
const A = { class: "flex flex-col justify-between" }, E = { class: "ml-auto h-full flex items-start justify-start" }, H = {
  key: 1,
  class: "border-t-gray-200 border-t-solid dark:border-t-slate-700 border-t pt-4 px-4 pb-4 flex absolute w-full bottom-0 justify-end mt-auto space-x-3"
}, U = /* @__PURE__ */ g({
  __name: "Drawer",
  props: T(),
  emits: ["update:visible"],
  setup(k, { emit: h }) {
    const l = k;
    w($, "ant-drawer");
    const { afterVisibleChange: r } = S(l), m = D(l, "visible");
    function c() {
      var e;
      h("update:visible", !1), (e = l.afterClose) == null || e.call(l);
    }
    const v = (...e) => {
      var s;
      (s = r == null ? void 0 : r.value) == null || s.call(r, ...e);
    };
    return (e, s) => (t(), u(i(N), j({
      visible: i(m),
      "onUpdate:visible": s[0] || (s[0] = (C) => x(m) ? m.value = C : null),
      title: null,
      footer: null,
      width: e.width,
      closable: !1,
      placement: e.placement,
      style: { padding: "0px" },
      drawerStyle: { padding: "0px" },
      bodyStyle: { padding: "0px" }
    }, e.$attrs, {
      onClose: c,
      onAfterVisibleChange: v
    }), {
      default: f(() => [
        e.title || e.closable ? (t(), n("div", {
          key: 0,
          class: a([[
            e.headerClass,
            {
              "bg-gradient-to-br from-primary-700 dark:from-primary-800 to-primary-900": e.primaryHeader
            }
          ], "p-5 flex flex-row items-center"])
        }, [
          d("div", A, [
            e.title ? (t(), n("h2", {
              key: 0,
              class: a([[e.titleClass], "mb-0 font-bold text-theme"])
            }, p(e.title), 3)) : o("", !0),
            d("p", {
              class: a([[e.descriptionClass], "mt-1 mb-0"])
            }, p(e.description), 3)
          ]),
          d("div", E, [
            e.closable ? (t(), n("span", {
              key: 0,
              class: a([[e.closeClass, { "!text-white text-white": e.primaryHeader }], "text-2xl text-slate-500 cursor-pointer hoverable-close hover:text-slate-700 dark:hover:text-slate-100 i-ic-round-close"]),
              onClick: c
            }, null, 2)) : o("", !0)
          ])
        ], 2)) : o("", !0),
        d("div", {
          style: { height: "500px" },
          class: a([[e.bodyClass], "pb-4 px-5 pt-0"])
        }, [
          B(e.$slots, "default")
        ], 2),
        e.showFooter ? (t(), n("div", H, [
          e.onCancel ? (t(), u(i(y), {
            key: 0,
            type: "border",
            color: "neutro",
            onClick: e.onCancel
          }, {
            default: f(() => [
              b(p(e.cancelText), 1)
            ]),
            _: 1
          }, 8, ["onClick"])) : o("", !0),
          e.onOk ? (t(), u(i(y), {
            key: 1,
            color: "primary",
            onClick: e.onOk
          }, {
            default: f(() => [
              b(p(e.okText), 1)
            ]),
            _: 1
          }, 8, ["onClick"])) : o("", !0)
        ])) : o("", !0)
      ]),
      _: 3
    }, 16, ["visible", "width", "placement"]));
  }
});
export {
  U as default
};
